@@ -6,7 +6,7 @@ use warnings;
 
 use DNS::LDNS ':all';
 
-our $VERSION = '0.05';
+our $VERSION = '0.50';
 
 sub new {
     my $class = shift;
@@ -68,9 +68,11 @@ sub DESTROY {
 }
 
 1;
+__END__
+
 =head1 NAME
 
-DNS::LDNS - Perl extension for the ldns library
+DNS::LDNS::DNSSecName - Dname with rrsets in a dnssec zone
 
 =head1 SYNOPSIS
 
